@@ -12,7 +12,7 @@ from moonworm.crawler.ethereum_state_provider import Web3StateProvider
 from moonworm.watch import watch_contract
 
 from .contracts import CU, ERC20, ERC721, CULands
-from .crawler.networks import Network
+from .crawler.utils import Network
 from .deployment import find_deployment_block
 from .generators.basic import (
     generate_contract_cli_content,
@@ -123,11 +123,11 @@ def handle_watch(args: argparse.Namespace) -> None:
         if args.network is None:
             raise ValueError("Please specify --network")
         network = Network.__members__[args.network]
-        from moonstreamdb.db import yield_db_session_ctx
 
         from .crawler.moonstream_ethereum_state_provider import (
             MoonstreamEthereumStateProvider,
         )
+        from .crawler.networks import yield_db_session_ctx
 
         state_provider = MoonstreamEthereumStateProvider(web3, network)
 
